# Jupyter notebooks

Simplified DP-class Domany-Kinzel model simulations are demonstrated in the following Jupyter notebooks:

- [**1d DP** for a very large lattice and large number of iterations, to validate $t$-decay of $\overline\rho(t)$ ](https://github.com/cstarkjp/DPRS/tree/main/notebooks/dp_1d.ipynb)

- [**2d DP** for a large lattice and large number of iterations, to validate $t$-decay of $\overline\rho(t)$ ](https://github.com/cstarkjp/DPRS/tree/main/notebooks/dp_3d.ipynb)

- [**3d DP** for a medium-size lattice and large number of iterations, to validate $t$-decay of $\overline\rho(t)$ ](https://github.com/cstarkjp/DPRS/tree/main/notebooks/dp_3d.ipynb)


<!-- # Python demos

- [dp_1d_quick.ipynb](https://github.com/cstarkjp/DPRS/tree/main/notebooks/dp_1d_quick.ipynb)


- [dp_1d.ipynb](https://github.com/cstarkjp/DPRS/tree/main/notebooks/dp_1d.ipynb)


- [dp_2d.ipynb](https://github.com/cstarkjp/DPRS/tree/main/notebooks/dp_2d.ipynb)
 -->
